Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(305)

Unified Diff: tests/service_tests/performance/java/PerformanceTest.java

Issue 1659163007: Rename fletch -> dartino (Closed) Base URL: https://github.com/dartino/sdk.git@master
Patch Set: address comments Created 4 years, 11 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: tests/service_tests/performance/java/PerformanceTest.java
diff --git a/tests/service_tests/performance/java/PerformanceTest.java b/tests/service_tests/performance/java/PerformanceTest.java
index fe08f78e0f4f81a7e1a4db38ef5e005b6089a77e..37a5865cea2e8bdefcb13c63b92d89022ec162ea 100644
--- a/tests/service_tests/performance/java/PerformanceTest.java
+++ b/tests/service_tests/performance/java/PerformanceTest.java
@@ -2,7 +2,7 @@
// for details. All rights reserved. Use of this source code is governed by a
// BSD-style license that can be found in the LICENSE.md file.
-import fletch.*;
+import dartino.*;
import java.io.FileInputStream;
import java.io.FileNotFoundException;
@@ -21,13 +21,13 @@ class PerformanceTest {
System.exit(1);
}
- // Load libfletch.so.
- System.loadLibrary("fletch");
+ // Load libdartino.so.
+ System.loadLibrary("dartino");
- // Setup Fletch.
- FletchApi.Setup();
- FletchServiceApi.Setup();
- FletchApi.AddDefaultSharedLibrary("libfletch.so");
+ // Setup Dartino.
+ DartinoApi.Setup();
+ DartinoServiceApi.Setup();
+ DartinoApi.AddDefaultSharedLibrary("libdartino.so");
try {
// Load snapshot and start dart code on a separate thread.

Powered by Google App Engine
This is Rietveld 408576698